from django.test import TestCase
from django.contrib.auth.models import User
from django.core.urlresolvers import reverse

from online.middleware import online


class SimpleTests(TestCase):
    def setUp(self):
        self.user = User.objects.create_user('thoas', 'thoas@localhost', '$ecret')

    def test_online(self):
        response = self.client.get(reverse('online_test'))

        self.assertEqual(response.status_code, 200)

        self.client.login(username='thoas', password='$ecret')

        response = self.client.get(reverse('online_test'))

        self.assertEqual(response.status_code, 200)

        self.assertTrue(online.exists(self.user))



import django

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': 'test_db',
        'USER': '',
        'PASSWORD': '',
        'HOST': '',
        'PORT': '',
    }
}

SITE_ID = 1
DEBUG = True

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'online',
    'online.tests',
]

ROOT_URLCONF = 'online.tests.urls'

TEMPLATE_DIRS = (
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'online.middleware.OnlineMiddleware',
)

SECRET_KEY = 'blabla'

if django.VERSION <= (1, 6):
    TEST_RUNNER = 'discover_runner.DiscoverRunner'
